@@ -1,10 +1,6 @@
+import unittest
 from textwrap import dedent
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
 import rope.base.exceptions
 from rope.refactor import change_signature
 from ropetest import testutils
